@@ -4,7 +4,7 @@ import importlib.util
 import inspect
 import os
 import re
-from typing import Dict, List, Optional
+from typing import Any, Dict, List, Optional
 
 import autoflake
 from pyflakes.messages import UndefinedExport, UndefinedName, UnusedImport
@@ -37,12 +37,15 @@ common_statements: Dict[str, str] = {
 class SourceCode:  # noqa: R090
     """Python source code entity."""
 
-    def __init__(self, source_code: str) -> None:
+    def __init__(
+        self, source_code: str, config: Optional[Dict[str, Any]] = None
+    ) -> None:
         """Initialize the object."""
         self.header: List[str] = []
         self.imports: List[str] = []
         self.typing: List[str] = []
         self.code: List[str] = []
+        self.config: Dict[str, Any] = config if config else {}
         self._trailing_newline = False
         self._split_code(source_code)
 
@@ -151,7 +154,7 @@ class SourceCode:  # noqa: R090
         """
         typing_start_line = len(self.header) + len(self.imports)
 
-        if len(source_lines) > 0 and re.match(
+        if typing_start_line < len(source_lines) and re.match(
             r"^if TYPE_CHECKING:$", source_lines[typing_start_line]
         ):
             self.typing.append(source_lines[typing_start_line])
@@ -356,8 +359,7 @@ class SourceCode:  # noqa: R090
         except KeyError:
             return None
 
-    @staticmethod
-    def _find_package_in_common_statements(name: str) -> Optional[str]:
+    def _find_package_in_common_statements(self, name: str) -> Optional[str]:
         """Search in the common statements the object name.
 
         Args:
@@ -366,8 +368,12 @@ class SourceCode:  # noqa: R090
         Returns:
             import_string
         """
-        if name in common_statements:
-            return common_statements[name]
+        local_common_statements = common_statements.copy()
+        if "common_statements" in self.config:
+            local_common_statements.update(self.config["common_statements"])
+
+        if name in local_common_statements:
+            return local_common_statements[name]
 
         return None
 
@@ -381,6 +387,10 @@ class SourceCode:  # noqa: R090
         object_name = import_name.split(".")[-1]
 
         for line in self.imports:
+            # Ignore the lines containing # noqa: autoimport
+            if re.match(r".*?# ?noqa:.*?autoimport.*", line):
+                continue
+
             # If it's the only line, remove it
             if re.match(fr"(from {package_name} )?import {object_name}$", line):
                 self.imports.remove(line)
